import type { BindingTypes as VueBindingTypes } from '@vue/compiler-dom';
export declare const DEFINE_COMPONENT_HELPER = "defineComponent";
export declare const USE_DEFAULTS_HELPER = "useDefaults";
export declare const TO_REFS_HELPER = "toRefs";
export declare const CSS_VARS_HELPER = "useCssVars";
export declare const UN_REF_HELPER = "unref";
export declare const BARE_CALL_MACROS: readonly ["vineExpose", "vineOptions", "vineStyle", "vineStyle.scoped", "vineCustomElement"];
export declare const VINE_MACROS: readonly ["vineProp", "vineProp.optional", "vineProp.withDefault", "vineEmits", "vineExpose", "vineOptions", "vineStyle", "vineStyle.scoped", "vineCustomElement"];
export declare const VINE_TAG_TEMPLATE_CALLER: readonly ["vine", "css", "scss", "sass", "less", "stylus", "postcss"];
export declare const SUPPORTED_CSS_LANGS: readonly ["css", "scss", "sass", "less", "stylus", "postcss"];
export declare const VUE_REACTIVITY_APIS: readonly ["ref", "shallowRef", "computed", "reactive", "readonly", "watchEffect", "watchPostEffect", "watchSyncEffect", "watch", "triggerRef", "customRef", "shallowReactive", "shallowReadonly", "toRaw", "markRaw", "effectScope", "getCurrentScope", "onScopeDispose"];
export declare const VUE_LIFECYCLE_HOOK_APIS: readonly ["onMounted", "onUpdated", "onUnmounted", "onBeforeMount", "onBeforeUpdate", "onBeforeUnmount", "onErrorCaptured", "onRenderTracked", "onRenderTriggered", "onActivated", "onDeactivated", "onServerPrefetch"];
export declare const TS_NODE_TYPES: string[];
/** This is derived from `@vue/compiler-core` */
export declare const VineBindingTypes: {
    /**
     * declared as a prop
     */
    readonly PROPS: VueBindingTypes.PROPS;
    /**
     * a local alias of a `<script setup>` destructured prop.
     * the original is stored in __propsAliases of the bindingMetadata object.
     */
    readonly PROPS_ALIASED: VueBindingTypes.PROPS_ALIASED;
    /**
     * a let binding (may or may not be a ref)
     */
    readonly SETUP_LET: VueBindingTypes.SETUP_LET;
    /**
     * a const binding that can never be a ref.
     * these bindings don't need `unref()` calls when processed in inlined
     * template expressions.
     */
    readonly SETUP_CONST: VueBindingTypes.SETUP_CONST;
    /**
     * a const binding that does not need `unref()`, but may be mutated.
     */
    readonly SETUP_REACTIVE_CONST: VueBindingTypes.SETUP_REACTIVE_CONST;
    /**
     * a const binding that may be a ref.
     */
    readonly SETUP_MAYBE_REF: VueBindingTypes.SETUP_MAYBE_REF;
    /**
     * bindings that are guaranteed to be refs
     */
    readonly SETUP_REF: VueBindingTypes.SETUP_REF;
    /**
     * a literal constant, e.g. 'foo', 1, true
     */
    readonly LITERAL_CONST: VueBindingTypes.LITERAL_CONST;
};
