export type ColorfulOptions = 'bold' | 'italic' | 'underline' | 'inverse' | 'strikethrough' | 'white' | 'grey' | 'black' | 'blue' | 'cyan' | 'green' | 'magenta' | 'red' | 'yellow' | 'bgWhite' | 'bgGrey' | 'bgBlack' | 'bgBlue' | 'bgCyan' | 'bgGreen' | 'bgMagenta' | 'bgRed' | 'bgYellow';
/**
 * Transform a string to ascii colorful string.
 *
 * ## Example
 * ```typescript
 * import { colorful } from 'my-pearls'
 *
 * colorful('This is red', ['red'])
 * colorful('This is green background', ['bgGreen'])
 * colorful('This is cyan and bold', ['cyan', 'bold'])
 * ```
 *
 * @param str String to be colored.
 * @param options Colorful options.
 * @returns Ascii colorful string.
 */
export declare function colorful(str: string, options?: ColorfulOptions[]): string;
export declare function createColorful(options: ColorfulOptions[]): (str: string) => string;
/**
 * Colorful string creator functions map.
 *
 * ## Example
 * ```typescript
 * import { Colorful } from 'my-pearls'
 *
 * Colorful.red('This is red')
 * Colorful.bgGreen('This is green background')
 * Colorful.bold('This is bold')
 * ```
 */
export declare const Colorful: Record<ColorfulOptions, (str: string) => string>;
